# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['HarRegistryArgs', 'HarRegistry']

@pulumi.input_type
class HarRegistryArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 package_type: pulumi.Input[_builtins.str],
                 parent_ref: pulumi.Input[_builtins.str],
                 space_ref: pulumi.Input[_builtins.str],
                 allowed_patterns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 blocked_patterns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 configs: Optional[pulumi.Input[Sequence[pulumi.Input['HarRegistryConfigArgs']]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a HarRegistry resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the registry
        :param pulumi.Input[_builtins.str] package_type: Type of package (DOCKER, HELM, MAVEN, etc.)
        :param pulumi.Input[_builtins.str] parent_ref: Parent reference for the registry (required for creation)
        :param pulumi.Input[_builtins.str] space_ref: Space reference for the registry (required for creation)
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_patterns: Allowed artifact patterns
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] blocked_patterns: Blocked artifact patterns
        :param pulumi.Input[Sequence[pulumi.Input['HarRegistryConfigArgs']]] configs: Configuration for the registry
        :param pulumi.Input[_builtins.str] description: Description of the registry
        """
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "package_type", package_type)
        pulumi.set(__self__, "parent_ref", parent_ref)
        pulumi.set(__self__, "space_ref", space_ref)
        if allowed_patterns is not None:
            pulumi.set(__self__, "allowed_patterns", allowed_patterns)
        if blocked_patterns is not None:
            pulumi.set(__self__, "blocked_patterns", blocked_patterns)
        if configs is not None:
            pulumi.set(__self__, "configs", configs)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the registry
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="packageType")
    def package_type(self) -> pulumi.Input[_builtins.str]:
        """
        Type of package (DOCKER, HELM, MAVEN, etc.)
        """
        return pulumi.get(self, "package_type")

    @package_type.setter
    def package_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "package_type", value)

    @_builtins.property
    @pulumi.getter(name="parentRef")
    def parent_ref(self) -> pulumi.Input[_builtins.str]:
        """
        Parent reference for the registry (required for creation)
        """
        return pulumi.get(self, "parent_ref")

    @parent_ref.setter
    def parent_ref(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "parent_ref", value)

    @_builtins.property
    @pulumi.getter(name="spaceRef")
    def space_ref(self) -> pulumi.Input[_builtins.str]:
        """
        Space reference for the registry (required for creation)
        """
        return pulumi.get(self, "space_ref")

    @space_ref.setter
    def space_ref(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "space_ref", value)

    @_builtins.property
    @pulumi.getter(name="allowedPatterns")
    def allowed_patterns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Allowed artifact patterns
        """
        return pulumi.get(self, "allowed_patterns")

    @allowed_patterns.setter
    def allowed_patterns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_patterns", value)

    @_builtins.property
    @pulumi.getter(name="blockedPatterns")
    def blocked_patterns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Blocked artifact patterns
        """
        return pulumi.get(self, "blocked_patterns")

    @blocked_patterns.setter
    def blocked_patterns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "blocked_patterns", value)

    @_builtins.property
    @pulumi.getter
    def configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['HarRegistryConfigArgs']]]]:
        """
        Configuration for the registry
        """
        return pulumi.get(self, "configs")

    @configs.setter
    def configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['HarRegistryConfigArgs']]]]):
        pulumi.set(self, "configs", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the registry
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _HarRegistryState:
    def __init__(__self__, *,
                 allowed_patterns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 blocked_patterns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 configs: Optional[pulumi.Input[Sequence[pulumi.Input['HarRegistryConfigArgs']]]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 package_type: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 space_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering HarRegistry resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_patterns: Allowed artifact patterns
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] blocked_patterns: Blocked artifact patterns
        :param pulumi.Input[Sequence[pulumi.Input['HarRegistryConfigArgs']]] configs: Configuration for the registry
        :param pulumi.Input[_builtins.str] created_at: Creation timestamp
        :param pulumi.Input[_builtins.str] description: Description of the registry
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the registry
        :param pulumi.Input[_builtins.str] package_type: Type of package (DOCKER, HELM, MAVEN, etc.)
        :param pulumi.Input[_builtins.str] parent_ref: Parent reference for the registry (required for creation)
        :param pulumi.Input[_builtins.str] space_ref: Space reference for the registry (required for creation)
        :param pulumi.Input[_builtins.str] url: URL of the registry
        """
        if allowed_patterns is not None:
            pulumi.set(__self__, "allowed_patterns", allowed_patterns)
        if blocked_patterns is not None:
            pulumi.set(__self__, "blocked_patterns", blocked_patterns)
        if configs is not None:
            pulumi.set(__self__, "configs", configs)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if package_type is not None:
            pulumi.set(__self__, "package_type", package_type)
        if parent_ref is not None:
            pulumi.set(__self__, "parent_ref", parent_ref)
        if space_ref is not None:
            pulumi.set(__self__, "space_ref", space_ref)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @_builtins.property
    @pulumi.getter(name="allowedPatterns")
    def allowed_patterns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Allowed artifact patterns
        """
        return pulumi.get(self, "allowed_patterns")

    @allowed_patterns.setter
    def allowed_patterns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_patterns", value)

    @_builtins.property
    @pulumi.getter(name="blockedPatterns")
    def blocked_patterns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Blocked artifact patterns
        """
        return pulumi.get(self, "blocked_patterns")

    @blocked_patterns.setter
    def blocked_patterns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "blocked_patterns", value)

    @_builtins.property
    @pulumi.getter
    def configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['HarRegistryConfigArgs']]]]:
        """
        Configuration for the registry
        """
        return pulumi.get(self, "configs")

    @configs.setter
    def configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['HarRegistryConfigArgs']]]]):
        pulumi.set(self, "configs", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Creation timestamp
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the registry
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the registry
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="packageType")
    def package_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of package (DOCKER, HELM, MAVEN, etc.)
        """
        return pulumi.get(self, "package_type")

    @package_type.setter
    def package_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "package_type", value)

    @_builtins.property
    @pulumi.getter(name="parentRef")
    def parent_ref(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Parent reference for the registry (required for creation)
        """
        return pulumi.get(self, "parent_ref")

    @parent_ref.setter
    def parent_ref(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent_ref", value)

    @_builtins.property
    @pulumi.getter(name="spaceRef")
    def space_ref(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Space reference for the registry (required for creation)
        """
        return pulumi.get(self, "space_ref")

    @space_ref.setter
    def space_ref(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "space_ref", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL of the registry
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "url", value)


@pulumi.type_token("harness:platform/harRegistry:HarRegistry")
class HarRegistry(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_patterns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 blocked_patterns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['HarRegistryConfigArgs', 'HarRegistryConfigArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 package_type: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 space_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating and managing Harness Registries.

        **Note:**
        > In Harness Artifact Registry, a **Virtual** registry is functionally equivalent to what is commonly referred to as a **Local** registry in other systems.
        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        # Example of a Virtual Registry
        virtual_registry = harness.platform.HarRegistry("virtual_registry",
            identifier="virtual_docker_registry",
            description="Virtual Docker Registry",
            space_ref="accountId/orgId/projectId",
            package_type="DOCKER",
            configs=[{
                "type": "VIRTUAL",
                "upstream_proxies": [
                    "registry1",
                    "registry2",
                ],
            }],
            parent_ref="accountId/orgId/projectId")
        # Example of an Upstream Registry with Authentication
        upstream_registry = harness.platform.HarRegistry("upstream_registry",
            identifier="upstream_helm_registry",
            description="Upstream Helm Registry",
            space_ref="accountId/orgId/projectId",
            package_type="HELM",
            configs=[{
                "type": "UPSTREAM",
                "source": "CUSTOM",
                "url": "https://helm.sh",
                "auths": [{
                    "auth_type": "UserPassword",
                    "user_name": "registry_user",
                    "secret_identifier": "registry_password",
                    "secret_space_path": "accountId/orgId/projectId",
                }],
            }],
            parent_ref="accountId/orgId/projectId")
        ```

        ## Import

        ### After Import

        bash

        pulumi preview

        pulumi up

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_patterns: Allowed artifact patterns
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] blocked_patterns: Blocked artifact patterns
        :param pulumi.Input[Sequence[pulumi.Input[Union['HarRegistryConfigArgs', 'HarRegistryConfigArgsDict']]]] configs: Configuration for the registry
        :param pulumi.Input[_builtins.str] description: Description of the registry
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the registry
        :param pulumi.Input[_builtins.str] package_type: Type of package (DOCKER, HELM, MAVEN, etc.)
        :param pulumi.Input[_builtins.str] parent_ref: Parent reference for the registry (required for creation)
        :param pulumi.Input[_builtins.str] space_ref: Space reference for the registry (required for creation)
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: HarRegistryArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating and managing Harness Registries.

        **Note:**
        > In Harness Artifact Registry, a **Virtual** registry is functionally equivalent to what is commonly referred to as a **Local** registry in other systems.
        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        # Example of a Virtual Registry
        virtual_registry = harness.platform.HarRegistry("virtual_registry",
            identifier="virtual_docker_registry",
            description="Virtual Docker Registry",
            space_ref="accountId/orgId/projectId",
            package_type="DOCKER",
            configs=[{
                "type": "VIRTUAL",
                "upstream_proxies": [
                    "registry1",
                    "registry2",
                ],
            }],
            parent_ref="accountId/orgId/projectId")
        # Example of an Upstream Registry with Authentication
        upstream_registry = harness.platform.HarRegistry("upstream_registry",
            identifier="upstream_helm_registry",
            description="Upstream Helm Registry",
            space_ref="accountId/orgId/projectId",
            package_type="HELM",
            configs=[{
                "type": "UPSTREAM",
                "source": "CUSTOM",
                "url": "https://helm.sh",
                "auths": [{
                    "auth_type": "UserPassword",
                    "user_name": "registry_user",
                    "secret_identifier": "registry_password",
                    "secret_space_path": "accountId/orgId/projectId",
                }],
            }],
            parent_ref="accountId/orgId/projectId")
        ```

        ## Import

        ### After Import

        bash

        pulumi preview

        pulumi up

        :param str resource_name: The name of the resource.
        :param HarRegistryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(HarRegistryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_patterns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 blocked_patterns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['HarRegistryConfigArgs', 'HarRegistryConfigArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 package_type: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 space_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = HarRegistryArgs.__new__(HarRegistryArgs)

            __props__.__dict__["allowed_patterns"] = allowed_patterns
            __props__.__dict__["blocked_patterns"] = blocked_patterns
            __props__.__dict__["configs"] = configs
            __props__.__dict__["description"] = description
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            if package_type is None and not opts.urn:
                raise TypeError("Missing required property 'package_type'")
            __props__.__dict__["package_type"] = package_type
            if parent_ref is None and not opts.urn:
                raise TypeError("Missing required property 'parent_ref'")
            __props__.__dict__["parent_ref"] = parent_ref
            if space_ref is None and not opts.urn:
                raise TypeError("Missing required property 'space_ref'")
            __props__.__dict__["space_ref"] = space_ref
            __props__.__dict__["created_at"] = None
            __props__.__dict__["url"] = None
        super(HarRegistry, __self__).__init__(
            'harness:platform/harRegistry:HarRegistry',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allowed_patterns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            blocked_patterns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['HarRegistryConfigArgs', 'HarRegistryConfigArgsDict']]]]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            package_type: Optional[pulumi.Input[_builtins.str]] = None,
            parent_ref: Optional[pulumi.Input[_builtins.str]] = None,
            space_ref: Optional[pulumi.Input[_builtins.str]] = None,
            url: Optional[pulumi.Input[_builtins.str]] = None) -> 'HarRegistry':
        """
        Get an existing HarRegistry resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_patterns: Allowed artifact patterns
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] blocked_patterns: Blocked artifact patterns
        :param pulumi.Input[Sequence[pulumi.Input[Union['HarRegistryConfigArgs', 'HarRegistryConfigArgsDict']]]] configs: Configuration for the registry
        :param pulumi.Input[_builtins.str] created_at: Creation timestamp
        :param pulumi.Input[_builtins.str] description: Description of the registry
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the registry
        :param pulumi.Input[_builtins.str] package_type: Type of package (DOCKER, HELM, MAVEN, etc.)
        :param pulumi.Input[_builtins.str] parent_ref: Parent reference for the registry (required for creation)
        :param pulumi.Input[_builtins.str] space_ref: Space reference for the registry (required for creation)
        :param pulumi.Input[_builtins.str] url: URL of the registry
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _HarRegistryState.__new__(_HarRegistryState)

        __props__.__dict__["allowed_patterns"] = allowed_patterns
        __props__.__dict__["blocked_patterns"] = blocked_patterns
        __props__.__dict__["configs"] = configs
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["package_type"] = package_type
        __props__.__dict__["parent_ref"] = parent_ref
        __props__.__dict__["space_ref"] = space_ref
        __props__.__dict__["url"] = url
        return HarRegistry(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="allowedPatterns")
    def allowed_patterns(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Allowed artifact patterns
        """
        return pulumi.get(self, "allowed_patterns")

    @_builtins.property
    @pulumi.getter(name="blockedPatterns")
    def blocked_patterns(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Blocked artifact patterns
        """
        return pulumi.get(self, "blocked_patterns")

    @_builtins.property
    @pulumi.getter
    def configs(self) -> pulumi.Output[Optional[Sequence['outputs.HarRegistryConfig']]]:
        """
        Configuration for the registry
        """
        return pulumi.get(self, "configs")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        Creation timestamp
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the registry
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the registry
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="packageType")
    def package_type(self) -> pulumi.Output[_builtins.str]:
        """
        Type of package (DOCKER, HELM, MAVEN, etc.)
        """
        return pulumi.get(self, "package_type")

    @_builtins.property
    @pulumi.getter(name="parentRef")
    def parent_ref(self) -> pulumi.Output[_builtins.str]:
        """
        Parent reference for the registry (required for creation)
        """
        return pulumi.get(self, "parent_ref")

    @_builtins.property
    @pulumi.getter(name="spaceRef")
    def space_ref(self) -> pulumi.Output[_builtins.str]:
        """
        Space reference for the registry (required for creation)
        """
        return pulumi.get(self, "space_ref")

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Output[_builtins.str]:
        """
        URL of the registry
        """
        return pulumi.get(self, "url")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetHubResult',
    'AwaitableGetHubResult',
    'get_hub',
    'get_hub_output',
]

@pulumi.output_type
class GetHubResult:
    """
    A collection of values returned by getHub.
    """
    def __init__(__self__, connector_id=None, created_at=None, description=None, id=None, is_available=None, is_default=None, last_synced_at=None, name=None, org_id=None, project_id=None, repo_branch=None, repo_name=None, tags=None, total_experiments=None, total_faults=None, updated_at=None):
        if connector_id and not isinstance(connector_id, str):
            raise TypeError("Expected argument 'connector_id' to be a str")
        pulumi.set(__self__, "connector_id", connector_id)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_available and not isinstance(is_available, bool):
            raise TypeError("Expected argument 'is_available' to be a bool")
        pulumi.set(__self__, "is_available", is_available)
        if is_default and not isinstance(is_default, bool):
            raise TypeError("Expected argument 'is_default' to be a bool")
        pulumi.set(__self__, "is_default", is_default)
        if last_synced_at and not isinstance(last_synced_at, str):
            raise TypeError("Expected argument 'last_synced_at' to be a str")
        pulumi.set(__self__, "last_synced_at", last_synced_at)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if repo_branch and not isinstance(repo_branch, str):
            raise TypeError("Expected argument 'repo_branch' to be a str")
        pulumi.set(__self__, "repo_branch", repo_branch)
        if repo_name and not isinstance(repo_name, str):
            raise TypeError("Expected argument 'repo_name' to be a str")
        pulumi.set(__self__, "repo_name", repo_name)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if total_experiments and not isinstance(total_experiments, int):
            raise TypeError("Expected argument 'total_experiments' to be a int")
        pulumi.set(__self__, "total_experiments", total_experiments)
        if total_faults and not isinstance(total_faults, int):
            raise TypeError("Expected argument 'total_faults' to be a int")
        pulumi.set(__self__, "total_faults", total_faults)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="connectorId")
    def connector_id(self) -> _builtins.str:
        """
        ID of the Git connector
        """
        return pulumi.get(self, "connector_id")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        Creation timestamp
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the chaos hub
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isAvailable")
    def is_available(self) -> _builtins.bool:
        """
        Whether the chaos hub is available
        """
        return pulumi.get(self, "is_available")

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> _builtins.bool:
        """
        Whether this is the default chaos hub
        """
        return pulumi.get(self, "is_default")

    @_builtins.property
    @pulumi.getter(name="lastSyncedAt")
    def last_synced_at(self) -> _builtins.str:
        """
        Timestamp of the last sync
        """
        return pulumi.get(self, "last_synced_at")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the chaos hub
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        The organization ID of the chaos hub
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        The project ID of the chaos hub
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="repoBranch")
    def repo_branch(self) -> _builtins.str:
        """
        Git repository branch
        """
        return pulumi.get(self, "repo_branch")

    @_builtins.property
    @pulumi.getter(name="repoName")
    def repo_name(self) -> _builtins.str:
        """
        Name of the Git repository
        """
        return pulumi.get(self, "repo_name")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags associated with the chaos hub
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="totalExperiments")
    def total_experiments(self) -> _builtins.int:
        """
        Total number of experiments in the hub
        """
        return pulumi.get(self, "total_experiments")

    @_builtins.property
    @pulumi.getter(name="totalFaults")
    def total_faults(self) -> _builtins.int:
        """
        Total number of faults in the hub
        """
        return pulumi.get(self, "total_faults")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        Last update timestamp
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetHubResult(GetHubResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetHubResult(
            connector_id=self.connector_id,
            created_at=self.created_at,
            description=self.description,
            id=self.id,
            is_available=self.is_available,
            is_default=self.is_default,
            last_synced_at=self.last_synced_at,
            name=self.name,
            org_id=self.org_id,
            project_id=self.project_id,
            repo_branch=self.repo_branch,
            repo_name=self.repo_name,
            tags=self.tags,
            total_experiments=self.total_experiments,
            total_faults=self.total_faults,
            updated_at=self.updated_at)


def get_hub(name: Optional[_builtins.str] = None,
            org_id: Optional[_builtins.str] = None,
            project_id: Optional[_builtins.str] = None,
            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetHubResult:
    """
    Data source for retrieving a Harness Chaos Hub

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.chaos.get_hub(name="<name>",
        org_id="<org_id>",
        project_id="<project_id>")
    ```


    :param _builtins.str name: Name of the chaos hub
    :param _builtins.str org_id: The organization ID of the chaos hub
    :param _builtins.str project_id: The project ID of the chaos hub
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:chaos/getHub:getHub', __args__, opts=opts, typ=GetHubResult).value

    return AwaitableGetHubResult(
        connector_id=pulumi.get(__ret__, 'connector_id'),
        created_at=pulumi.get(__ret__, 'created_at'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        is_available=pulumi.get(__ret__, 'is_available'),
        is_default=pulumi.get(__ret__, 'is_default'),
        last_synced_at=pulumi.get(__ret__, 'last_synced_at'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        repo_branch=pulumi.get(__ret__, 'repo_branch'),
        repo_name=pulumi.get(__ret__, 'repo_name'),
        tags=pulumi.get(__ret__, 'tags'),
        total_experiments=pulumi.get(__ret__, 'total_experiments'),
        total_faults=pulumi.get(__ret__, 'total_faults'),
        updated_at=pulumi.get(__ret__, 'updated_at'))
def get_hub_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                   org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                   project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetHubResult]:
    """
    Data source for retrieving a Harness Chaos Hub

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.chaos.get_hub(name="<name>",
        org_id="<org_id>",
        project_id="<project_id>")
    ```


    :param _builtins.str name: Name of the chaos hub
    :param _builtins.str org_id: The organization ID of the chaos hub
    :param _builtins.str project_id: The project ID of the chaos hub
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:chaos/getHub:getHub', __args__, opts=opts, typ=GetHubResult)
    return __ret__.apply(lambda __response__: GetHubResult(
        connector_id=pulumi.get(__response__, 'connector_id'),
        created_at=pulumi.get(__response__, 'created_at'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        is_available=pulumi.get(__response__, 'is_available'),
        is_default=pulumi.get(__response__, 'is_default'),
        last_synced_at=pulumi.get(__response__, 'last_synced_at'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        repo_branch=pulumi.get(__response__, 'repo_branch'),
        repo_name=pulumi.get(__response__, 'repo_name'),
        tags=pulumi.get(__response__, 'tags'),
        total_experiments=pulumi.get(__response__, 'total_experiments'),
        total_faults=pulumi.get(__response__, 'total_faults'),
        updated_at=pulumi.get(__response__, 'updated_at')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ServiceArgs', 'Service']

@pulumi.input_type
class ServiceArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 fetch_resolved_yaml: Optional[pulumi.Input[_builtins.bool]] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 git_details: Optional[pulumi.Input['ServiceGitDetailsArgs']] = None,
                 import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_force_import: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Service resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] fetch_resolved_yaml: to fetch resoled service yaml
        :param pulumi.Input[_builtins.bool] force_delete: Enable this flag for force deletion of service
        :param pulumi.Input['ServiceGitDetailsArgs'] git_details: Contains parameters related to Git Experience for remote entities
        :param pulumi.Input[_builtins.bool] import_from_git: import service from git
        :param pulumi.Input[_builtins.bool] is_force_import: force import service from remote even if same file path already exist
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] yaml: Service YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        pulumi.set(__self__, "identifier", identifier)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if fetch_resolved_yaml is not None:
            pulumi.set(__self__, "fetch_resolved_yaml", fetch_resolved_yaml)
        if force_delete is not None:
            pulumi.set(__self__, "force_delete", force_delete)
        if git_details is not None:
            pulumi.set(__self__, "git_details", git_details)
        if import_from_git is not None:
            pulumi.set(__self__, "import_from_git", import_from_git)
        if is_force_import is not None:
            pulumi.set(__self__, "is_force_import", is_force_import)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if yaml is not None:
            pulumi.set(__self__, "yaml", yaml)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="fetchResolvedYaml")
    def fetch_resolved_yaml(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        to fetch resoled service yaml
        """
        return pulumi.get(self, "fetch_resolved_yaml")

    @fetch_resolved_yaml.setter
    def fetch_resolved_yaml(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "fetch_resolved_yaml", value)

    @_builtins.property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable this flag for force deletion of service
        """
        return pulumi.get(self, "force_delete")

    @force_delete.setter
    def force_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force_delete", value)

    @_builtins.property
    @pulumi.getter(name="gitDetails")
    def git_details(self) -> Optional[pulumi.Input['ServiceGitDetailsArgs']]:
        """
        Contains parameters related to Git Experience for remote entities
        """
        return pulumi.get(self, "git_details")

    @git_details.setter
    def git_details(self, value: Optional[pulumi.Input['ServiceGitDetailsArgs']]):
        pulumi.set(self, "git_details", value)

    @_builtins.property
    @pulumi.getter(name="importFromGit")
    def import_from_git(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        import service from git
        """
        return pulumi.get(self, "import_from_git")

    @import_from_git.setter
    def import_from_git(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "import_from_git", value)

    @_builtins.property
    @pulumi.getter(name="isForceImport")
    def is_force_import(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        force import service from remote even if same file path already exist
        """
        return pulumi.get(self, "is_force_import")

    @is_force_import.setter
    def is_force_import(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_force_import", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Service YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        return pulumi.get(self, "yaml")

    @yaml.setter
    def yaml(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "yaml", value)


@pulumi.input_type
class _ServiceState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 fetch_resolved_yaml: Optional[pulumi.Input[_builtins.bool]] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 git_details: Optional[pulumi.Input['ServiceGitDetailsArgs']] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_force_import: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Service resources.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] fetch_resolved_yaml: to fetch resoled service yaml
        :param pulumi.Input[_builtins.bool] force_delete: Enable this flag for force deletion of service
        :param pulumi.Input['ServiceGitDetailsArgs'] git_details: Contains parameters related to Git Experience for remote entities
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.bool] import_from_git: import service from git
        :param pulumi.Input[_builtins.bool] is_force_import: force import service from remote even if same file path already exist
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] yaml: Service YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if fetch_resolved_yaml is not None:
            pulumi.set(__self__, "fetch_resolved_yaml", fetch_resolved_yaml)
        if force_delete is not None:
            pulumi.set(__self__, "force_delete", force_delete)
        if git_details is not None:
            pulumi.set(__self__, "git_details", git_details)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if import_from_git is not None:
            pulumi.set(__self__, "import_from_git", import_from_git)
        if is_force_import is not None:
            pulumi.set(__self__, "is_force_import", is_force_import)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if yaml is not None:
            pulumi.set(__self__, "yaml", yaml)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="fetchResolvedYaml")
    def fetch_resolved_yaml(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        to fetch resoled service yaml
        """
        return pulumi.get(self, "fetch_resolved_yaml")

    @fetch_resolved_yaml.setter
    def fetch_resolved_yaml(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "fetch_resolved_yaml", value)

    @_builtins.property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable this flag for force deletion of service
        """
        return pulumi.get(self, "force_delete")

    @force_delete.setter
    def force_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force_delete", value)

    @_builtins.property
    @pulumi.getter(name="gitDetails")
    def git_details(self) -> Optional[pulumi.Input['ServiceGitDetailsArgs']]:
        """
        Contains parameters related to Git Experience for remote entities
        """
        return pulumi.get(self, "git_details")

    @git_details.setter
    def git_details(self, value: Optional[pulumi.Input['ServiceGitDetailsArgs']]):
        pulumi.set(self, "git_details", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="importFromGit")
    def import_from_git(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        import service from git
        """
        return pulumi.get(self, "import_from_git")

    @import_from_git.setter
    def import_from_git(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "import_from_git", value)

    @_builtins.property
    @pulumi.getter(name="isForceImport")
    def is_force_import(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        force import service from remote even if same file path already exist
        """
        return pulumi.get(self, "is_force_import")

    @is_force_import.setter
    def is_force_import(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_force_import", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Service YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        return pulumi.get(self, "yaml")

    @yaml.setter
    def yaml(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "yaml", value)


@pulumi.type_token("harness:platform/service:Service")
class Service(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 fetch_resolved_yaml: Optional[pulumi.Input[_builtins.bool]] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 git_details: Optional[pulumi.Input[Union['ServiceGitDetailsArgs', 'ServiceGitDetailsArgsDict']]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_force_import: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating a Harness project.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.Service("example",
            identifier="identifier",
            name="name",
            description="test",
            org_id="org_id",
            project_id="project_id",
            git_details={
                "branch_name": "branchName",
                "commit_message": "commitMessage",
                "file_path": "filePath",
                "connector_ref": "connectorRef",
                "store_type": "REMOTE",
                "repo_name": "repoName",
            },
            yaml=\"\"\"service:
          name: name
          identifier: identifier
          serviceDefinition:
            spec:
              manifests:
                - manifest:
                    identifier: manifest1
                    type: K8sManifest
                    spec:
                      store:
                        type: Github
                        spec:
                          connectorRef: <+input>
                          gitFetchType: Branch
                          paths:
                            - files1
                          repoName: <+input>
                          branch: master
                      skipResourceVersioning: false
              configFiles:
                - configFile:
                    identifier: configFile1
                    spec:
                      store:
                        type: Harness
                        spec:
                          files:
                            - <+org.description>
              variables:
                - name: var1
                  type: String
                  value: val1
                - name: var2
                  type: String
                  value: val2
            type: Kubernetes
          gitOpsEnabled: false
        \"\"\")
        ### Importing Service from Git
        test = harness.platform.Service("test",
            identifier="id",
            name="name",
            org_id="org_id",
            project_id="project_id",
            import_from_git=True,
            git_details={
                "store_type": "REMOTE",
                "connector_ref": "account.DoNotDeleteGitX",
                "repo_name": "pcf_practice",
                "file_path": ".harness/accountService.yaml",
                "branch": "main",
            })
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level service

        ```sh
        $ pulumi import harness:platform/service:Service example <service_id>
        ```

        Import org level service

        ```sh
        $ pulumi import harness:platform/service:Service example <org_id>/<service_id>
        ```

        Import project level service

        ```sh
        $ pulumi import harness:platform/service:Service example <org_id>/<project_id>/<service_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] fetch_resolved_yaml: to fetch resoled service yaml
        :param pulumi.Input[_builtins.bool] force_delete: Enable this flag for force deletion of service
        :param pulumi.Input[Union['ServiceGitDetailsArgs', 'ServiceGitDetailsArgsDict']] git_details: Contains parameters related to Git Experience for remote entities
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.bool] import_from_git: import service from git
        :param pulumi.Input[_builtins.bool] is_force_import: force import service from remote even if same file path already exist
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] yaml: Service YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServiceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness project.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.Service("example",
            identifier="identifier",
            name="name",
            description="test",
            org_id="org_id",
            project_id="project_id",
            git_details={
                "branch_name": "branchName",
                "commit_message": "commitMessage",
                "file_path": "filePath",
                "connector_ref": "connectorRef",
                "store_type": "REMOTE",
                "repo_name": "repoName",
            },
            yaml=\"\"\"service:
          name: name
          identifier: identifier
          serviceDefinition:
            spec:
              manifests:
                - manifest:
                    identifier: manifest1
                    type: K8sManifest
                    spec:
                      store:
                        type: Github
                        spec:
                          connectorRef: <+input>
                          gitFetchType: Branch
                          paths:
                            - files1
                          repoName: <+input>
                          branch: master
                      skipResourceVersioning: false
              configFiles:
                - configFile:
                    identifier: configFile1
                    spec:
                      store:
                        type: Harness
                        spec:
                          files:
                            - <+org.description>
              variables:
                - name: var1
                  type: String
                  value: val1
                - name: var2
                  type: String
                  value: val2
            type: Kubernetes
          gitOpsEnabled: false
        \"\"\")
        ### Importing Service from Git
        test = harness.platform.Service("test",
            identifier="id",
            name="name",
            org_id="org_id",
            project_id="project_id",
            import_from_git=True,
            git_details={
                "store_type": "REMOTE",
                "connector_ref": "account.DoNotDeleteGitX",
                "repo_name": "pcf_practice",
                "file_path": ".harness/accountService.yaml",
                "branch": "main",
            })
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level service

        ```sh
        $ pulumi import harness:platform/service:Service example <service_id>
        ```

        Import org level service

        ```sh
        $ pulumi import harness:platform/service:Service example <org_id>/<service_id>
        ```

        Import project level service

        ```sh
        $ pulumi import harness:platform/service:Service example <org_id>/<project_id>/<service_id>
        ```

        :param str resource_name: The name of the resource.
        :param ServiceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServiceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 fetch_resolved_yaml: Optional[pulumi.Input[_builtins.bool]] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 git_details: Optional[pulumi.Input[Union['ServiceGitDetailsArgs', 'ServiceGitDetailsArgsDict']]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_force_import: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServiceArgs.__new__(ServiceArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["fetch_resolved_yaml"] = fetch_resolved_yaml
            __props__.__dict__["force_delete"] = force_delete
            __props__.__dict__["git_details"] = git_details
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["import_from_git"] = import_from_git
            __props__.__dict__["is_force_import"] = is_force_import
            __props__.__dict__["name"] = name
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["yaml"] = yaml
        super(Service, __self__).__init__(
            'harness:platform/service:Service',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            fetch_resolved_yaml: Optional[pulumi.Input[_builtins.bool]] = None,
            force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
            git_details: Optional[pulumi.Input[Union['ServiceGitDetailsArgs', 'ServiceGitDetailsArgsDict']]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
            is_force_import: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            yaml: Optional[pulumi.Input[_builtins.str]] = None) -> 'Service':
        """
        Get an existing Service resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] fetch_resolved_yaml: to fetch resoled service yaml
        :param pulumi.Input[_builtins.bool] force_delete: Enable this flag for force deletion of service
        :param pulumi.Input[Union['ServiceGitDetailsArgs', 'ServiceGitDetailsArgsDict']] git_details: Contains parameters related to Git Experience for remote entities
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.bool] import_from_git: import service from git
        :param pulumi.Input[_builtins.bool] is_force_import: force import service from remote even if same file path already exist
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] yaml: Service YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServiceState.__new__(_ServiceState)

        __props__.__dict__["description"] = description
        __props__.__dict__["fetch_resolved_yaml"] = fetch_resolved_yaml
        __props__.__dict__["force_delete"] = force_delete
        __props__.__dict__["git_details"] = git_details
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["import_from_git"] = import_from_git
        __props__.__dict__["is_force_import"] = is_force_import
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["yaml"] = yaml
        return Service(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="fetchResolvedYaml")
    def fetch_resolved_yaml(self) -> pulumi.Output[_builtins.bool]:
        """
        to fetch resoled service yaml
        """
        return pulumi.get(self, "fetch_resolved_yaml")

    @_builtins.property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable this flag for force deletion of service
        """
        return pulumi.get(self, "force_delete")

    @_builtins.property
    @pulumi.getter(name="gitDetails")
    def git_details(self) -> pulumi.Output['outputs.ServiceGitDetails']:
        """
        Contains parameters related to Git Experience for remote entities
        """
        return pulumi.get(self, "git_details")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="importFromGit")
    def import_from_git(self) -> pulumi.Output[_builtins.bool]:
        """
        import service from git
        """
        return pulumi.get(self, "import_from_git")

    @_builtins.property
    @pulumi.getter(name="isForceImport")
    def is_force_import(self) -> pulumi.Output[_builtins.bool]:
        """
        force import service from remote even if same file path already exist
        """
        return pulumi.get(self, "is_force_import")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> pulumi.Output[_builtins.str]:
        """
        Service YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        return pulumi.get(self, "yaml")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetApplicationResult',
    'AwaitableGetApplicationResult',
    'get_application',
    'get_application_output',
]

@pulumi.output_type
class GetApplicationResult:
    """
    A collection of values returned by getApplication.
    """
    def __init__(__self__, description=None, git_sync_connector_id=None, git_sync_enabled=None, id=None, is_manual_trigger_authorized=None, name=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if git_sync_connector_id and not isinstance(git_sync_connector_id, str):
            raise TypeError("Expected argument 'git_sync_connector_id' to be a str")
        pulumi.set(__self__, "git_sync_connector_id", git_sync_connector_id)
        if git_sync_enabled and not isinstance(git_sync_enabled, bool):
            raise TypeError("Expected argument 'git_sync_enabled' to be a bool")
        pulumi.set(__self__, "git_sync_enabled", git_sync_enabled)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_manual_trigger_authorized and not isinstance(is_manual_trigger_authorized, bool):
            raise TypeError("Expected argument 'is_manual_trigger_authorized' to be a bool")
        pulumi.set(__self__, "is_manual_trigger_authorized", is_manual_trigger_authorized)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[_builtins.str]:
        """
        The application description
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="gitSyncConnectorId")
    def git_sync_connector_id(self) -> Optional[_builtins.str]:
        """
        The id of the git sync connector
        """
        return pulumi.get(self, "git_sync_connector_id")

    @_builtins.property
    @pulumi.getter(name="gitSyncEnabled")
    def git_sync_enabled(self) -> Optional[_builtins.bool]:
        """
        True if git sync is enabled on this application
        """
        return pulumi.get(self, "git_sync_enabled")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the application
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isManualTriggerAuthorized")
    def is_manual_trigger_authorized(self) -> Optional[_builtins.bool]:
        """
        When this is set to true, all manual triggers will require API Key authorization
        """
        return pulumi.get(self, "is_manual_trigger_authorized")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        The name of the application
        """
        return pulumi.get(self, "name")


class AwaitableGetApplicationResult(GetApplicationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetApplicationResult(
            description=self.description,
            git_sync_connector_id=self.git_sync_connector_id,
            git_sync_enabled=self.git_sync_enabled,
            id=self.id,
            is_manual_trigger_authorized=self.is_manual_trigger_authorized,
            name=self.name)


def get_application(description: Optional[_builtins.str] = None,
                    git_sync_connector_id: Optional[_builtins.str] = None,
                    git_sync_enabled: Optional[_builtins.bool] = None,
                    id: Optional[_builtins.str] = None,
                    is_manual_trigger_authorized: Optional[_builtins.bool] = None,
                    name: Optional[_builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetApplicationResult:
    """
    Data source for retrieving a Harness application


    :param _builtins.str description: The application description
    :param _builtins.str git_sync_connector_id: The id of the git sync connector
    :param _builtins.bool git_sync_enabled: True if git sync is enabled on this application
    :param _builtins.str id: Unique identifier of the application
    :param _builtins.bool is_manual_trigger_authorized: When this is set to true, all manual triggers will require API Key authorization
    :param _builtins.str name: The name of the application
    """
    __args__ = dict()
    __args__['description'] = description
    __args__['gitSyncConnectorId'] = git_sync_connector_id
    __args__['gitSyncEnabled'] = git_sync_enabled
    __args__['id'] = id
    __args__['isManualTriggerAuthorized'] = is_manual_trigger_authorized
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:index/getApplication:getApplication', __args__, opts=opts, typ=GetApplicationResult).value

    return AwaitableGetApplicationResult(
        description=pulumi.get(__ret__, 'description'),
        git_sync_connector_id=pulumi.get(__ret__, 'git_sync_connector_id'),
        git_sync_enabled=pulumi.get(__ret__, 'git_sync_enabled'),
        id=pulumi.get(__ret__, 'id'),
        is_manual_trigger_authorized=pulumi.get(__ret__, 'is_manual_trigger_authorized'),
        name=pulumi.get(__ret__, 'name'))
def get_application_output(description: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           git_sync_connector_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           git_sync_enabled: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                           id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           is_manual_trigger_authorized: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                           name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetApplicationResult]:
    """
    Data source for retrieving a Harness application


    :param _builtins.str description: The application description
    :param _builtins.str git_sync_connector_id: The id of the git sync connector
    :param _builtins.bool git_sync_enabled: True if git sync is enabled on this application
    :param _builtins.str id: Unique identifier of the application
    :param _builtins.bool is_manual_trigger_authorized: When this is set to true, all manual triggers will require API Key authorization
    :param _builtins.str name: The name of the application
    """
    __args__ = dict()
    __args__['description'] = description
    __args__['gitSyncConnectorId'] = git_sync_connector_id
    __args__['gitSyncEnabled'] = git_sync_enabled
    __args__['id'] = id
    __args__['isManualTriggerAuthorized'] = is_manual_trigger_authorized
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:index/getApplication:getApplication', __args__, opts=opts, typ=GetApplicationResult)
    return __ret__.apply(lambda __response__: GetApplicationResult(
        description=pulumi.get(__response__, 'description'),
        git_sync_connector_id=pulumi.get(__response__, 'git_sync_connector_id'),
        git_sync_enabled=pulumi.get(__response__, 'git_sync_enabled'),
        id=pulumi.get(__response__, 'id'),
        is_manual_trigger_authorized=pulumi.get(__response__, 'is_manual_trigger_authorized'),
        name=pulumi.get(__response__, 'name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GitopsApplicationsetArgs', 'GitopsApplicationset']

@pulumi.input_type
class GitopsApplicationsetArgs:
    def __init__(__self__, *,
                 agent_id: pulumi.Input[_builtins.str],
                 applicationset: pulumi.Input['GitopsApplicationsetApplicationsetArgs'],
                 org_id: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.str],
                 upsert: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a GitopsApplicationset resource.
        :param pulumi.Input[_builtins.str] agent_id: Agent identifier of the GitOps applicationset.
        :param pulumi.Input['GitopsApplicationsetApplicationsetArgs'] applicationset: Definition of the GitOps applicationset resource.
        :param pulumi.Input[_builtins.str] org_id: Organization identifier of the GitOps applicationset.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the GitOps applicationset.
        :param pulumi.Input[_builtins.bool] upsert: Indicates if the GitOps application should be updated if existing and inserted if not.
        """
        pulumi.set(__self__, "agent_id", agent_id)
        pulumi.set(__self__, "applicationset", applicationset)
        pulumi.set(__self__, "org_id", org_id)
        pulumi.set(__self__, "project_id", project_id)
        if upsert is not None:
            pulumi.set(__self__, "upsert", upsert)

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> pulumi.Input[_builtins.str]:
        """
        Agent identifier of the GitOps applicationset.
        """
        return pulumi.get(self, "agent_id")

    @agent_id.setter
    def agent_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "agent_id", value)

    @_builtins.property
    @pulumi.getter
    def applicationset(self) -> pulumi.Input['GitopsApplicationsetApplicationsetArgs']:
        """
        Definition of the GitOps applicationset resource.
        """
        return pulumi.get(self, "applicationset")

    @applicationset.setter
    def applicationset(self, value: pulumi.Input['GitopsApplicationsetApplicationsetArgs']):
        pulumi.set(self, "applicationset", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Input[_builtins.str]:
        """
        Organization identifier of the GitOps applicationset.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        Project identifier of the GitOps applicationset.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def upsert(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the GitOps application should be updated if existing and inserted if not.
        """
        return pulumi.get(self, "upsert")

    @upsert.setter
    def upsert(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "upsert", value)


@pulumi.input_type
class _GitopsApplicationsetState:
    def __init__(__self__, *,
                 agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 applicationset: Optional[pulumi.Input['GitopsApplicationsetApplicationsetArgs']] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 upsert: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering GitopsApplicationset resources.
        :param pulumi.Input[_builtins.str] agent_id: Agent identifier of the GitOps applicationset.
        :param pulumi.Input['GitopsApplicationsetApplicationsetArgs'] applicationset: Definition of the GitOps applicationset resource.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the GitOps applicationset. This is a unique identifier for the applicationset generated automatically.
        :param pulumi.Input[_builtins.str] org_id: Organization identifier of the GitOps applicationset.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the GitOps applicationset.
        :param pulumi.Input[_builtins.bool] upsert: Indicates if the GitOps application should be updated if existing and inserted if not.
        """
        if agent_id is not None:
            pulumi.set(__self__, "agent_id", agent_id)
        if applicationset is not None:
            pulumi.set(__self__, "applicationset", applicationset)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if upsert is not None:
            pulumi.set(__self__, "upsert", upsert)

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Agent identifier of the GitOps applicationset.
        """
        return pulumi.get(self, "agent_id")

    @agent_id.setter
    def agent_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "agent_id", value)

    @_builtins.property
    @pulumi.getter
    def applicationset(self) -> Optional[pulumi.Input['GitopsApplicationsetApplicationsetArgs']]:
        """
        Definition of the GitOps applicationset resource.
        """
        return pulumi.get(self, "applicationset")

    @applicationset.setter
    def applicationset(self, value: Optional[pulumi.Input['GitopsApplicationsetApplicationsetArgs']]):
        pulumi.set(self, "applicationset", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the GitOps applicationset. This is a unique identifier for the applicationset generated automatically.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Organization identifier of the GitOps applicationset.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project identifier of the GitOps applicationset.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def upsert(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the GitOps application should be updated if existing and inserted if not.
        """
        return pulumi.get(self, "upsert")

    @upsert.setter
    def upsert(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "upsert", value)


@pulumi.type_token("harness:platform/gitopsApplicationset:GitopsApplicationset")
class GitopsApplicationset(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 applicationset: Optional[pulumi.Input[Union['GitopsApplicationsetApplicationsetArgs', 'GitopsApplicationsetApplicationsetArgsDict']]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 upsert: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        Resource for managing a Harness Gitops Applicationset. Please note this resource is in an alpha/experimental state and is subject to change.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        # Example 1: Cluster Generator
        cluster_generator = harness.platform.GitopsApplicationset("cluster_generator",
            org_id="default",
            project_id="projectId",
            agent_id="account.agentuseast1",
            upsert=True,
            applicationset={
                "metadata": {
                    "name": "cluster-appset",
                    "namespace": "argocd",
                },
                "spec": {
                    "go_template": True,
                    "go_template_options": ["missingkey=error"],
                    "generators": [{
                        "clusters": [{
                            "enabled": True,
                        }],
                    }],
                    "template": {
                        "metadata": {
                            "name": "{{.name}}-guestbook",
                            "labels": {
                                "env": "dev",
                            },
                        },
                        "spec": {
                            "project": "default",
                            "sources": [{
                                "repo_url": "https://github.com/argoproj/argocd-example-apps.git",
                                "path": "helm-guestbook",
                                "target_revision": "HEAD",
                            }],
                            "destination": {
                                "server": "{{.url}}",
                                "namespace": "app-ns-{{.name}}",
                            },
                        },
                    },
                },
            })
        # Example 2: List Generator
        list_generator = harness.platform.GitopsApplicationset("list_generator",
            org_id="default",
            project_id="projectId",
            agent_id="account.agentuseast1",
            upsert=True,
            applicationset={
                "metadata": {
                    "name": "list-appset",
                },
                "spec": {
                    "go_template": True,
                    "go_template_options": ["missingkey=error"],
                    "generators": [{
                        "lists": [{
                            "elements": [
                                {
                                    "cluster": "engineering-dev",
                                    "url": "https://kubernetes.default.svc",
                                },
                                {
                                    "cluster": "engineering-prod",
                                    "url": "https://kubernetes.prod.svc",
                                },
                            ],
                        }],
                    }],
                    "template": {
                        "metadata": {
                            "name": "{{.cluster}}-guestbook",
                        },
                        "spec": {
                            "project": "default",
                            "sources": [{
                                "repo_url": "https://github.com/argoproj/argocd-example-apps.git",
                                "path": "helm-guestbook",
                                "target_revision": "HEAD",
                            }],
                            "destination": {
                                "server": "{{.url}}",
                                "namespace": "default",
                            },
                        },
                    },
                },
            })
        # Example 3: Git Generator with Files
        git_files = harness.platform.GitopsApplicationset("git_files",
            org_id="default",
            project_id="projectId",
            agent_id="account.agentuseast1",
            upsert=True,
            applicationset={
                "metadata": {
                    "name": "git-files-appset",
                },
                "spec": {
                    "generators": [{
                        "gits": [{
                            "repo_url": "https://github.com/example/config-repo",
                            "revision": "main",
                            "files": [{
                                "path": "apps/*/config.json",
                            }],
                        }],
                    }],
                    "template": {
                        "metadata": {
                            "name": "{{.path.basename}}-app",
                        },
                        "spec": {
                            "project": "default",
                            "sources": [{
                                "repo_url": "https://github.com/example/app-repo",
                                "path": "{{.path.path}}",
                                "target_revision": "main",
                            }],
                            "destination": {
                                "server": "https://kubernetes.default.svc",
                                "namespace": "{{.path.basename}}",
                            },
                        },
                    },
                },
            })
        # Example 4: Git Generator with Directories
        git_directories = harness.platform.GitopsApplicationset("git_directories",
            org_id="default",
            project_id="projectId",
            agent_id="account.agentuseast1",
            upsert=True,
            applicationset={
                "metadata": {
                    "name": "git-directories-appset",
                },
                "spec": {
                    "generators": [{
                        "gits": [{
                            "repo_url": "https://github.com/argoproj/argo-cd.git",
                            "revision": "HEAD",
                            "directories": [{
                                "path": "applicationset/examples/git-generator-directory/cluster-addons/*",
                                "exclude": False,
                            }],
                        }],
                    }],
                    "template": {
                        "metadata": {
                            "name": "{{.path.basename}}-addon",
                        },
                        "spec": {
                            "project": "default",
                            "sources": [{
                                "repo_url": "https://github.com/argoproj/argo-cd.git",
                                "path": "{{.path.path}}",
                                "target_revision": "HEAD",
                            }],
                            "destination": {
                                "server": "https://kubernetes.default.svc",
                                "namespace": "{{.path.basename}}",
                            },
                            "sync_policy": {
                                "automated": {
                                    "prune": True,
                                    "self_heal": True,
                                },
                            },
                        },
                    },
                },
            })
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import gitOps applicationset with account level agent, agent id has account prefix #

        ```sh
        $ pulumi import harness:platform/gitopsApplicationset:GitopsApplicationset example <organization_id>/<project_id>/<agent_id>/<identifier>
        ```

        Import gitOps applicationset with org level agent, agent id has org prefix #

        ```sh
        $ pulumi import harness:platform/gitopsApplicationset:GitopsApplicationset example <organization_id>/<project_id>/<agent_id>/<identifier>
        ```

        Import gitOps applicationset with project level agent #

        ```sh
        $ pulumi import harness:platform/gitopsApplicationset:GitopsApplicationset example <organization_id>/<project_id>/<agent_id>/<identifier>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] agent_id: Agent identifier of the GitOps applicationset.
        :param pulumi.Input[Union['GitopsApplicationsetApplicationsetArgs', 'GitopsApplicationsetApplicationsetArgsDict']] applicationset: Definition of the GitOps applicationset resource.
        :param pulumi.Input[_builtins.str] org_id: Organization identifier of the GitOps applicationset.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the GitOps applicationset.
        :param pulumi.Input[_builtins.bool] upsert: Indicates if the GitOps application should be updated if existing and inserted if not.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GitopsApplicationsetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for managing a Harness Gitops Applicationset. Please note this resource is in an alpha/experimental state and is subject to change.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        # Example 1: Cluster Generator
        cluster_generator = harness.platform.GitopsApplicationset("cluster_generator",
            org_id="default",
            project_id="projectId",
            agent_id="account.agentuseast1",
            upsert=True,
            applicationset={
                "metadata": {
                    "name": "cluster-appset",
                    "namespace": "argocd",
                },
                "spec": {
                    "go_template": True,
                    "go_template_options": ["missingkey=error"],
                    "generators": [{
                        "clusters": [{
                            "enabled": True,
                        }],
                    }],
                    "template": {
                        "metadata": {
                            "name": "{{.name}}-guestbook",
                            "labels": {
                                "env": "dev",
                            },
                        },
                        "spec": {
                            "project": "default",
                            "sources": [{
                                "repo_url": "https://github.com/argoproj/argocd-example-apps.git",
                                "path": "helm-guestbook",
                                "target_revision": "HEAD",
                            }],
                            "destination": {
                                "server": "{{.url}}",
                                "namespace": "app-ns-{{.name}}",
                            },
                        },
                    },
                },
            })
        # Example 2: List Generator
        list_generator = harness.platform.GitopsApplicationset("list_generator",
            org_id="default",
            project_id="projectId",
            agent_id="account.agentuseast1",
            upsert=True,
            applicationset={
                "metadata": {
                    "name": "list-appset",
                },
                "spec": {
                    "go_template": True,
                    "go_template_options": ["missingkey=error"],
                    "generators": [{
                        "lists": [{
                            "elements": [
                                {
                                    "cluster": "engineering-dev",
                                    "url": "https://kubernetes.default.svc",
                                },
                                {
                                    "cluster": "engineering-prod",
                                    "url": "https://kubernetes.prod.svc",
                                },
                            ],
                        }],
                    }],
                    "template": {
                        "metadata": {
                            "name": "{{.cluster}}-guestbook",
                        },
                        "spec": {
                            "project": "default",
                            "sources": [{
                                "repo_url": "https://github.com/argoproj/argocd-example-apps.git",
                                "path": "helm-guestbook",
                                "target_revision": "HEAD",
                            }],
                            "destination": {
                                "server": "{{.url}}",
                                "namespace": "default",
                            },
                        },
                    },
                },
            })
        # Example 3: Git Generator with Files
        git_files = harness.platform.GitopsApplicationset("git_files",
            org_id="default",
            project_id="projectId",
            agent_id="account.agentuseast1",
            upsert=True,
            applicationset={
                "metadata": {
                    "name": "git-files-appset",
                },
                "spec": {
                    "generators": [{
                        "gits": [{
                            "repo_url": "https://github.com/example/config-repo",
                            "revision": "main",
                            "files": [{
                                "path": "apps/*/config.json",
                            }],
                        }],
                    }],
                    "template": {
                        "metadata": {
                            "name": "{{.path.basename}}-app",
                        },
                        "spec": {
                            "project": "default",
                            "sources": [{
                                "repo_url": "https://github.com/example/app-repo",
                                "path": "{{.path.path}}",
                                "target_revision": "main",
                            }],
                            "destination": {
                                "server": "https://kubernetes.default.svc",
                                "namespace": "{{.path.basename}}",
                            },
                        },
                    },
                },
            })
        # Example 4: Git Generator with Directories
        git_directories = harness.platform.GitopsApplicationset("git_directories",
            org_id="default",
            project_id="projectId",
            agent_id="account.agentuseast1",
            upsert=True,
            applicationset={
                "metadata": {
                    "name": "git-directories-appset",
                },
                "spec": {
                    "generators": [{
                        "gits": [{
                            "repo_url": "https://github.com/argoproj/argo-cd.git",
                            "revision": "HEAD",
                            "directories": [{
                                "path": "applicationset/examples/git-generator-directory/cluster-addons/*",
                                "exclude": False,
                            }],
                        }],
                    }],
                    "template": {
                        "metadata": {
                            "name": "{{.path.basename}}-addon",
                        },
                        "spec": {
                            "project": "default",
                            "sources": [{
                                "repo_url": "https://github.com/argoproj/argo-cd.git",
                                "path": "{{.path.path}}",
                                "target_revision": "HEAD",
                            }],
                            "destination": {
                                "server": "https://kubernetes.default.svc",
                                "namespace": "{{.path.basename}}",
                            },
                            "sync_policy": {
                                "automated": {
                                    "prune": True,
                                    "self_heal": True,
                                },
                            },
                        },
                    },
                },
            })
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import gitOps applicationset with account level agent, agent id has account prefix #

        ```sh
        $ pulumi import harness:platform/gitopsApplicationset:GitopsApplicationset example <organization_id>/<project_id>/<agent_id>/<identifier>
        ```

        Import gitOps applicationset with org level agent, agent id has org prefix #

        ```sh
        $ pulumi import harness:platform/gitopsApplicationset:GitopsApplicationset example <organization_id>/<project_id>/<agent_id>/<identifier>
        ```

        Import gitOps applicationset with project level agent #

        ```sh
        $ pulumi import harness:platform/gitopsApplicationset:GitopsApplicationset example <organization_id>/<project_id>/<agent_id>/<identifier>
        ```

        :param str resource_name: The name of the resource.
        :param GitopsApplicationsetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GitopsApplicationsetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 applicationset: Optional[pulumi.Input[Union['GitopsApplicationsetApplicationsetArgs', 'GitopsApplicationsetApplicationsetArgsDict']]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 upsert: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GitopsApplicationsetArgs.__new__(GitopsApplicationsetArgs)

            if agent_id is None and not opts.urn:
                raise TypeError("Missing required property 'agent_id'")
            __props__.__dict__["agent_id"] = agent_id
            if applicationset is None and not opts.urn:
                raise TypeError("Missing required property 'applicationset'")
            __props__.__dict__["applicationset"] = applicationset
            if org_id is None and not opts.urn:
                raise TypeError("Missing required property 'org_id'")
            __props__.__dict__["org_id"] = org_id
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["upsert"] = upsert
            __props__.__dict__["identifier"] = None
        super(GitopsApplicationset, __self__).__init__(
            'harness:platform/gitopsApplicationset:GitopsApplicationset',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            agent_id: Optional[pulumi.Input[_builtins.str]] = None,
            applicationset: Optional[pulumi.Input[Union['GitopsApplicationsetApplicationsetArgs', 'GitopsApplicationsetApplicationsetArgsDict']]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            upsert: Optional[pulumi.Input[_builtins.bool]] = None) -> 'GitopsApplicationset':
        """
        Get an existing GitopsApplicationset resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] agent_id: Agent identifier of the GitOps applicationset.
        :param pulumi.Input[Union['GitopsApplicationsetApplicationsetArgs', 'GitopsApplicationsetApplicationsetArgsDict']] applicationset: Definition of the GitOps applicationset resource.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the GitOps applicationset. This is a unique identifier for the applicationset generated automatically.
        :param pulumi.Input[_builtins.str] org_id: Organization identifier of the GitOps applicationset.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the GitOps applicationset.
        :param pulumi.Input[_builtins.bool] upsert: Indicates if the GitOps application should be updated if existing and inserted if not.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GitopsApplicationsetState.__new__(_GitopsApplicationsetState)

        __props__.__dict__["agent_id"] = agent_id
        __props__.__dict__["applicationset"] = applicationset
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["upsert"] = upsert
        return GitopsApplicationset(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> pulumi.Output[_builtins.str]:
        """
        Agent identifier of the GitOps applicationset.
        """
        return pulumi.get(self, "agent_id")

    @_builtins.property
    @pulumi.getter
    def applicationset(self) -> pulumi.Output['outputs.GitopsApplicationsetApplicationset']:
        """
        Definition of the GitOps applicationset resource.
        """
        return pulumi.get(self, "applicationset")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier of the GitOps applicationset. This is a unique identifier for the applicationset generated automatically.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[_builtins.str]:
        """
        Organization identifier of the GitOps applicationset.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        Project identifier of the GitOps applicationset.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def upsert(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates if the GitOps application should be updated if existing and inserted if not.
        """
        return pulumi.get(self, "upsert")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetCcmFiltersResult',
    'AwaitableGetCcmFiltersResult',
    'get_ccm_filters',
    'get_ccm_filters_output',
]

@pulumi.output_type
class GetCcmFiltersResult:
    """
    A collection of values returned by getCcmFilters.
    """
    def __init__(__self__, filter_properties=None, filter_visibility=None, id=None, identifier=None, name=None, org_id=None, project_id=None, type=None):
        if filter_properties and not isinstance(filter_properties, list):
            raise TypeError("Expected argument 'filter_properties' to be a list")
        pulumi.set(__self__, "filter_properties", filter_properties)
        if filter_visibility and not isinstance(filter_visibility, str):
            raise TypeError("Expected argument 'filter_visibility' to be a str")
        pulumi.set(__self__, "filter_visibility", filter_visibility)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="filterProperties")
    def filter_properties(self) -> Sequence['outputs.GetCcmFiltersFilterPropertyResult']:
        """
        Properties of the filter entity defined in Harness.
        """
        return pulumi.get(self, "filter_properties")

    @_builtins.property
    @pulumi.getter(name="filterVisibility")
    def filter_visibility(self) -> _builtins.str:
        """
        This indicates visibility of filter. By default, everyone can view this filter.
        """
        return pulumi.get(self, "filter_visibility")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the Filter.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Organization Identifier for the Entity.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Project Identifier for the Entity.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Type of filter.
        """
        return pulumi.get(self, "type")


class AwaitableGetCcmFiltersResult(GetCcmFiltersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCcmFiltersResult(
            filter_properties=self.filter_properties,
            filter_visibility=self.filter_visibility,
            id=self.id,
            identifier=self.identifier,
            name=self.name,
            org_id=self.org_id,
            project_id=self.project_id,
            type=self.type)


def get_ccm_filters(identifier: Optional[_builtins.str] = None,
                    org_id: Optional[_builtins.str] = None,
                    project_id: Optional[_builtins.str] = None,
                    type: Optional[_builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCcmFiltersResult:
    """
    Data source for retrieving a Harness CCM Filter.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    test = harness.platform.get_ccm_filters(identifier="identifier",
        org_id="org_id",
        project_id="project_id",
        type="CCMRecommendation")
    ```


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str org_id: Organization Identifier for the Entity.
    :param _builtins.str project_id: Project Identifier for the Entity.
    :param _builtins.str type: Type of filter.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getCcmFilters:getCcmFilters', __args__, opts=opts, typ=GetCcmFiltersResult).value

    return AwaitableGetCcmFiltersResult(
        filter_properties=pulumi.get(__ret__, 'filter_properties'),
        filter_visibility=pulumi.get(__ret__, 'filter_visibility'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        type=pulumi.get(__ret__, 'type'))
def get_ccm_filters_output(identifier: Optional[pulumi.Input[_builtins.str]] = None,
                           org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           type: Optional[pulumi.Input[_builtins.str]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCcmFiltersResult]:
    """
    Data source for retrieving a Harness CCM Filter.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    test = harness.platform.get_ccm_filters(identifier="identifier",
        org_id="org_id",
        project_id="project_id",
        type="CCMRecommendation")
    ```


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str org_id: Organization Identifier for the Entity.
    :param _builtins.str project_id: Project Identifier for the Entity.
    :param _builtins.str type: Type of filter.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['type'] = type
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getCcmFilters:getCcmFilters', __args__, opts=opts, typ=GetCcmFiltersResult)
    return __ret__.apply(lambda __response__: GetCcmFiltersResult(
        filter_properties=pulumi.get(__response__, 'filter_properties'),
        filter_visibility=pulumi.get(__response__, 'filter_visibility'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        type=pulumi.get(__response__, 'type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['TriggersArgs', 'Triggers']

@pulumi.input_type
class TriggersArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 org_id: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.str],
                 target_id: pulumi.Input[_builtins.str],
                 yaml: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 if_match: Optional[pulumi.Input[_builtins.str]] = None,
                 ignore_error: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 webhook_url: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Triggers resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] target_id: Identifier of the target pipeline
        :param pulumi.Input[_builtins.str] yaml: trigger yaml. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] if_match: if-Match
        :param pulumi.Input[_builtins.bool] ignore_error: ignore error default false
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] webhook_url: The webhook URL if the trigger is type `Webhook`.
        """
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "org_id", org_id)
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "target_id", target_id)
        pulumi.set(__self__, "yaml", yaml)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if if_match is not None:
            pulumi.set(__self__, "if_match", if_match)
        if ignore_error is not None:
            pulumi.set(__self__, "ignore_error", ignore_error)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if webhook_url is not None:
            pulumi.set(__self__, "webhook_url", webhook_url)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="targetId")
    def target_id(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of the target pipeline
        """
        return pulumi.get(self, "target_id")

    @target_id.setter
    def target_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "target_id", value)

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> pulumi.Input[_builtins.str]:
        """
        trigger yaml. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        return pulumi.get(self, "yaml")

    @yaml.setter
    def yaml(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "yaml", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="ifMatch")
    def if_match(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        if-Match
        """
        return pulumi.get(self, "if_match")

    @if_match.setter
    def if_match(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "if_match", value)

    @_builtins.property
    @pulumi.getter(name="ignoreError")
    def ignore_error(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        ignore error default false
        """
        return pulumi.get(self, "ignore_error")

    @ignore_error.setter
    def ignore_error(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "ignore_error", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="webhookUrl")
    def webhook_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The webhook URL if the trigger is type `Webhook`.
        """
        return pulumi.get(self, "webhook_url")

    @webhook_url.setter
    def webhook_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "webhook_url", value)


@pulumi.input_type
class _TriggersState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 if_match: Optional[pulumi.Input[_builtins.str]] = None,
                 ignore_error: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 target_id: Optional[pulumi.Input[_builtins.str]] = None,
                 webhook_url: Optional[pulumi.Input[_builtins.str]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Triggers resources.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] if_match: if-Match
        :param pulumi.Input[_builtins.bool] ignore_error: ignore error default false
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] target_id: Identifier of the target pipeline
        :param pulumi.Input[_builtins.str] webhook_url: The webhook URL if the trigger is type `Webhook`.
        :param pulumi.Input[_builtins.str] yaml: trigger yaml. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if if_match is not None:
            pulumi.set(__self__, "if_match", if_match)
        if ignore_error is not None:
            pulumi.set(__self__, "ignore_error", ignore_error)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if target_id is not None:
            pulumi.set(__self__, "target_id", target_id)
        if webhook_url is not None:
            pulumi.set(__self__, "webhook_url", webhook_url)
        if yaml is not None:
            pulumi.set(__self__, "yaml", yaml)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="ifMatch")
    def if_match(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        if-Match
        """
        return pulumi.get(self, "if_match")

    @if_match.setter
    def if_match(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "if_match", value)

    @_builtins.property
    @pulumi.getter(name="ignoreError")
    def ignore_error(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        ignore error default false
        """
        return pulumi.get(self, "ignore_error")

    @ignore_error.setter
    def ignore_error(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "ignore_error", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="targetId")
    def target_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the target pipeline
        """
        return pulumi.get(self, "target_id")

    @target_id.setter
    def target_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_id", value)

    @_builtins.property
    @pulumi.getter(name="webhookUrl")
    def webhook_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The webhook URL if the trigger is type `Webhook`.
        """
        return pulumi.get(self, "webhook_url")

    @webhook_url.setter
    def webhook_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "webhook_url", value)

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        trigger yaml. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        return pulumi.get(self, "yaml")

    @yaml.setter
    def yaml(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "yaml", value)


@pulumi.type_token("harness:platform/triggers:Triggers")
class Triggers(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 if_match: Optional[pulumi.Input[_builtins.str]] = None,
                 ignore_error: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 target_id: Optional[pulumi.Input[_builtins.str]] = None,
                 webhook_url: Optional[pulumi.Input[_builtins.str]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating triggers in Harness.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.Triggers("example",
            identifier="identifier",
            org_id="orgIdentifer",
            project_id="projectIdentifier",
            name="name",
            target_id="pipelineIdentifier",
            yaml=\"\"\"trigger:
          name: name
          identifier: identifier
          enabled: true
          description: \\"\\"
          tags: {}
          projectIdentifier: projectIdentifier
          orgIdentifier: orgIdentifer
          pipelineIdentifier: pipelineIdentifier
          source:
            type: Webhook
            spec:
              type: Github
              spec:
                type: Push
                spec:
                  connectorRef: account.TestAccResourceConnectorGithub_Ssh_IZBeG
                  autoAbortPreviousExecutions: false
                  payloadConditions:
                  - key: changedFiles
                    operator: Equals
                    value: value
                  - key: targetBranch
                    operator: Equals
                    value: value
                  headerConditions: []
                  repoName: repoName
                  actions: []
          inputYaml: |
            pipeline: {}\\

        \"\"\")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import trigger

        ```sh
        $ pulumi import harness:platform/triggers:Triggers example <org_id>/<project_id>/<target_id>/<triggers_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] if_match: if-Match
        :param pulumi.Input[_builtins.bool] ignore_error: ignore error default false
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] target_id: Identifier of the target pipeline
        :param pulumi.Input[_builtins.str] webhook_url: The webhook URL if the trigger is type `Webhook`.
        :param pulumi.Input[_builtins.str] yaml: trigger yaml. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TriggersArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating triggers in Harness.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.Triggers("example",
            identifier="identifier",
            org_id="orgIdentifer",
            project_id="projectIdentifier",
            name="name",
            target_id="pipelineIdentifier",
            yaml=\"\"\"trigger:
          name: name
          identifier: identifier
          enabled: true
          description: \\"\\"
          tags: {}
          projectIdentifier: projectIdentifier
          orgIdentifier: orgIdentifer
          pipelineIdentifier: pipelineIdentifier
          source:
            type: Webhook
            spec:
              type: Github
              spec:
                type: Push
                spec:
                  connectorRef: account.TestAccResourceConnectorGithub_Ssh_IZBeG
                  autoAbortPreviousExecutions: false
                  payloadConditions:
                  - key: changedFiles
                    operator: Equals
                    value: value
                  - key: targetBranch
                    operator: Equals
                    value: value
                  headerConditions: []
                  repoName: repoName
                  actions: []
          inputYaml: |
            pipeline: {}\\

        \"\"\")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import trigger

        ```sh
        $ pulumi import harness:platform/triggers:Triggers example <org_id>/<project_id>/<target_id>/<triggers_id>
        ```

        :param str resource_name: The name of the resource.
        :param TriggersArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TriggersArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 if_match: Optional[pulumi.Input[_builtins.str]] = None,
                 ignore_error: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 target_id: Optional[pulumi.Input[_builtins.str]] = None,
                 webhook_url: Optional[pulumi.Input[_builtins.str]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TriggersArgs.__new__(TriggersArgs)

            __props__.__dict__["description"] = description
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["if_match"] = if_match
            __props__.__dict__["ignore_error"] = ignore_error
            __props__.__dict__["name"] = name
            if org_id is None and not opts.urn:
                raise TypeError("Missing required property 'org_id'")
            __props__.__dict__["org_id"] = org_id
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["tags"] = tags
            if target_id is None and not opts.urn:
                raise TypeError("Missing required property 'target_id'")
            __props__.__dict__["target_id"] = target_id
            __props__.__dict__["webhook_url"] = webhook_url
            if yaml is None and not opts.urn:
                raise TypeError("Missing required property 'yaml'")
            __props__.__dict__["yaml"] = yaml
        super(Triggers, __self__).__init__(
            'harness:platform/triggers:Triggers',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            if_match: Optional[pulumi.Input[_builtins.str]] = None,
            ignore_error: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            target_id: Optional[pulumi.Input[_builtins.str]] = None,
            webhook_url: Optional[pulumi.Input[_builtins.str]] = None,
            yaml: Optional[pulumi.Input[_builtins.str]] = None) -> 'Triggers':
        """
        Get an existing Triggers resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] if_match: if-Match
        :param pulumi.Input[_builtins.bool] ignore_error: ignore error default false
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] target_id: Identifier of the target pipeline
        :param pulumi.Input[_builtins.str] webhook_url: The webhook URL if the trigger is type `Webhook`.
        :param pulumi.Input[_builtins.str] yaml: trigger yaml. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TriggersState.__new__(_TriggersState)

        __props__.__dict__["description"] = description
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["if_match"] = if_match
        __props__.__dict__["ignore_error"] = ignore_error
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["target_id"] = target_id
        __props__.__dict__["webhook_url"] = webhook_url
        __props__.__dict__["yaml"] = yaml
        return Triggers(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="ifMatch")
    def if_match(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        if-Match
        """
        return pulumi.get(self, "if_match")

    @_builtins.property
    @pulumi.getter(name="ignoreError")
    def ignore_error(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        ignore error default false
        """
        return pulumi.get(self, "ignore_error")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="targetId")
    def target_id(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier of the target pipeline
        """
        return pulumi.get(self, "target_id")

    @_builtins.property
    @pulumi.getter(name="webhookUrl")
    def webhook_url(self) -> pulumi.Output[_builtins.str]:
        """
        The webhook URL if the trigger is type `Webhook`.
        """
        return pulumi.get(self, "webhook_url")

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> pulumi.Output[_builtins.str]:
        """
        trigger yaml. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        return pulumi.get(self, "yaml")

